@@ -49,6 +49,58 @@ gibbs_one_layer_vec <- function(x, y, nmcmc, verb, initial, true_g, settings,
   return(list(g = g, theta = theta, tau2 = tau2, x_approx = x_approx))
 }
 
+# One layer Gibbs with Vecchia SEPARABLE ------------------------------------------------
+
+gibbs_one_layer_vec_sep <- function(x, y, nmcmc, verb, initial, true_g, settings, 
+                                v, m, x_approx = NULL) {
+  
+  d <- ncol(x)
+  if (is.null(x_approx)) 
+    x_approx <- create_approx(x, m)
+  
+  g <- vector(length = nmcmc)
+  if (is.null(true_g)) g[1] <- initial$g else g[1] <- true_g
+  theta <- matrix(nrow = nmcmc, ncol = d)
+  if (length(initial$theta) == 1) initial$theta <- rep(initial$theta, d)
+  theta[1, ] <- initial$theta
+  tau2 <- vector(length = nmcmc)
+  tau2[1] <- initial$tau2
+  ll <- NULL
+  
+  for (j in 2:nmcmc) {
+    
+    if(verb) if(j %% 500 == 0) cat(j, '\n')
+    
+    # Sample nugget (g)
+    if (is.null(true_g)) {
+      samp <- sample_g_vec(y, g[j - 1], theta[j - 1, ], alpha = settings$alpha$g, 
+                           beta = settings$beta$g, l = settings$l, 
+                           u = settings$u, ll_prev = ll, approx = x_approx, 
+                           v = v, sep = TRUE)
+      g[j] <- samp$g
+      ll <- samp$ll
+    } else g[j] <- true_g
+    
+    # Sample length scale (theta)
+    for (i in 1:d) {
+      samp <- sample_theta_vec_sep(y, g[j], theta[j - 1, ], index = i,
+                                alpha = settings$alpha$theta,
+                                beta = settings$beta$theta, l = settings$l, 
+                                u = settings$u, ll_prev = ll, 
+                                approx = x_approx, v = v, tau2 = TRUE)
+      theta[j, i] <- samp$theta
+      ll <- samp$ll
+      if (i == 1) { # update tau2 (repeat original value if nothing was accepted)
+        if (is.null(samp$tau2)) tau2[j] <- tau2[j - 1] else tau2[j] <- samp$tau2
+      } else { # only update tau2 if there was an acceptance
+        if (!is.null(samp$tau2)) tau2[j] <- samp$tau2
+      }
+    }
+  } # end of j for loop
+  
+  return(list(g = g, theta = theta, tau2 = tau2, x_approx = x_approx))
+}
+
 # Two layer Gibbs with Vecchia ------------------------------------------------
 
 gibbs_two_layer_vec <- function(x, y, nmcmc, D, verb, initial, true_g, settings, 
